==> localnews-base-api-3.10.0-sources.jar: com/bxm/localnews/base/controller/LocationController.java <==
package com.bxm.localnews.base.controller;


import java.util.List;

import com.bxm.localnews.base.service.AreaInfoService;
import com.bxm.localnews.base.service.LocationRelationService;
import com.bxm.localnews.base.service.LocationService;
import com.bxm.localnews.common.dto.*;
import com.bxm.localnews.common.param.ListAreaLocationParam;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.AreaInfo;
import com.bxm.localnews.common.vo.BasicParam;
import com.bxm.localnews.common.vo.Json;

import com.bxm.newidea.component.vo.ResponseJson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "1-04 地址基础服务接口", description = "地址基础服务接口")
@RequestMapping("/api/area")
@RestController
public class LocationController {

    /**
     * 日志对象
     */
    private static final Logger LOG = LoggerFactory.getLogger(LocationController.class);

    private LocationService locationService;

    private AreaInfoService areaInfoService;

    private LocationRelationService locationRelationService;

    @Autowired
    public LocationController(LocationService locationService,
                              AreaInfoService areaInfoService,
                              LocationRelationService locationRelationService) {
        this.locationService = locationService;
        this.areaInfoService = areaInfoService;
        this.locationRelationService = locationRelationService;
    }

    @GetMapping(value = "/division")
    @ApiOperation(value = "1-04-1 获得省份信息", notes = "获得全国省份信息")
    public Json<List<AreaDivisionDTO>> listAreaDivisionAdditional() {
        return ResultUtil.genSuccessResult(locationService.listAreaDivisionDTO(null));
    }

    @GetMapping(value = "/division/{parentCode}")
    @ApiOperation(value = "1-04-2 根据上级编码获取省市区县街道", notes = "如果pcode为空,则返回最上层的省份信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "parentCode", value = "父级编号", required = true),
    })
    public Json<List<AreaDivisionDTO>> listAreaDivision(@PathVariable String parentCode) {
        return ResultUtil.genSuccessResult(locationService.listAreaDivisionDTO(parentCode));
    }

    @GetMapping(value = "/location")
    @ApiOperation(value = "1-04-3 获取定位列表", notes = "包含开放的城市列表和热门城市列表,并根据首字母进行分组")
    public Json<LocationMeta> listAreaLocation(ListAreaLocationParam param) {
        return ResultUtil.genSuccessResult(locationService.listLocation(param));
    }

    @GetMapping(value = "/info/{code}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
    })
    @ApiOperation(value = "1-04-4 根据code获取区域信息", notes = "")
    public Json<AreaInfo> getAreaInfo(@PathVariable String code, BasicParam basicParam) {
        if ("undefined".equals(code)) {
            return ResultUtil.genFailedResult("code非法，无法定位:"+code);
        }
        return ResultUtil.genSuccessResult(areaInfoService.getAreaInfo(code,basicParam));
    }

    @GetMapping(value = "/speech")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "code", value = "区域编号 一般为12位"),
            @ApiImplicitParam(name = "type", value = "话术类型 1：微信 2：朋友圈 5:小程序微信 6：小程序朋友圈 11:聊天室分享配置 12：邀请分享激活VIP 13:联系商家信息")
    })
    @ApiOperation(value = "1-04-5 根据code获取区域的话术", notes = "在分享至微信的时候,需要显示的文字：包括微信、朋友圈的话术，其中包含内容和ID")
    public Json<LocationRelationDTO> getAreaSpeech(@RequestParam String code, @RequestParam Byte type) {

        LocationRelationDTO locationRelation = locationRelationService.getLocationRelation(code, type);
        return ResultUtil.genSuccessResult(locationRelation);
    }

    @GetMapping(value = "/location/{code}/customer")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
    })
    @ApiOperation(value = "1-04-7 根据地区code获取客服信息", notes = "获取客服信息-二维码和微信号")
    public Json<CustomerServiceDTO> getCustomerServiceByCode(@PathVariable String code) {

        try {
            CustomerServiceDTO customerServiceDTO = locationService.getCustomerServiceInfo(code);
            if (null == customerServiceDTO) {
                return ResultUtil.genFailedResult("获取客服信息失败");
            }

            return ResultUtil.genSuccessResult(customerServiceDTO);
        } catch (Exception e) {
            LOG.error("获取客服信息异常", e);
            return ResultUtil.genFailedResult("获取客服信息异常");
        }
    }

    @GetMapping(value = "/public/speech")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "code", value = "区域编号 一般为12位"),
            @ApiImplicitParam(name = "type", value = "话术类型 1：微信 2：朋友圈 5:小程序微信 6：小程序朋友圈,11聊天室分享配置")
    })
    @ApiOperation(value = "1-04-8 站外根据code获取区域的话术", notes = "在分享至微信的时候,需要显示的文字：包括微信、朋友圈的话术，其中包含内容和ID")
    public Json<LocationRelationDTO> getAreaSpeechForPublic(@RequestParam String code, @RequestParam Byte type) {
        LocationRelationDTO locationRelation = locationRelationService.getLocationRelation(code, type);
        return ResultUtil.genSuccessResult(locationRelation);
    }

    @GetMapping(value = "/location/{code}/group/customer/phone")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
    })
    @ApiOperation(value = "1-04-9 根据地区code获取团购客服电话", notes = "获取团购客服电话")
    public Json<GroupCustomerPhoneDTO> getGroupCustomerServiceByCode(@PathVariable String code) {

        try {
            GroupCustomerPhoneDTO groupCustomerPhoneDTO = locationService.getGroupCustomerPhoneServiceInfo(code);
            if (null == groupCustomerPhoneDTO) {
                return ResultUtil.genFailedResult("获取团购客服电话失败");
            }

            return ResultUtil.genSuccessResult(groupCustomerPhoneDTO);
        } catch (Exception e) {
            LOG.error("获取团购客服电话异常", e);
            return ResultUtil.genFailedResult("获取客服信息异常");
        }
    }

    @GetMapping(value = "/public/{code}/officialAccount")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
    })
    @ApiOperation(value = "1-04-10 根据地区code获取公众号信息", notes = "获取公众号信息")
    public ResponseJson<OfficialAccountDTO> getOfficialAccountByCode(@PathVariable String code) {
        return ResponseJson.ok(locationService.getOfficialAccountInfo(code));
    }
}

==> localnews-base-api-3.11.0-sources.jar: com/bxm/localnews/base/controller/LocationController.java <==
package com.bxm.localnews.base.controller;


import java.util.List;

import com.bxm.localnews.base.service.AreaInfoService;
import com.bxm.localnews.base.service.LocationRelationService;
import com.bxm.localnews.base.service.LocationService;
import com.bxm.localnews.common.dto.*;
import com.bxm.localnews.common.param.ListAreaLocationParam;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.AreaInfo;
import com.bxm.localnews.common.vo.BasicParam;
import com.bxm.localnews.common.vo.Json;

import com.bxm.newidea.component.vo.Message;
import com.bxm.newidea.component.vo.ResponseJson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "1-04 地址基础服务接口", description = "地址基础服务接口")
@RequestMapping("/api/area")
@RestController
public class LocationController {

    /**
     * 日志对象
     */
    private static final Logger LOG = LoggerFactory.getLogger(LocationController.class);

    private LocationService locationService;

    private AreaInfoService areaInfoService;

    private LocationRelationService locationRelationService;

    @Autowired
    public LocationController(LocationService locationService,
                              AreaInfoService areaInfoService,
                              LocationRelationService locationRelationService) {
        this.locationService = locationService;
        this.areaInfoService = areaInfoService;
        this.locationRelationService = locationRelationService;
    }

    @GetMapping(value = "/division")
    @ApiOperation(value = "1-04-1 获得省份信息", notes = "获得全国省份信息")
    public Json<List<AreaDivisionDTO>> listAreaDivisionAdditional() {
        return ResultUtil.genSuccessResult(locationService.listAreaDivisionDTO(null));
    }

    @GetMapping(value = "/division/{parentCode}")
    @ApiOperation(value = "1-04-2 根据上级编码获取省市区县街道", notes = "如果pcode为空,则返回最上层的省份信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "parentCode", value = "父级编号", required = true),
    })
    public Json<List<AreaDivisionDTO>> listAreaDivision(@PathVariable String parentCode) {
        return ResultUtil.genSuccessResult(locationService.listAreaDivisionDTO(parentCode));
    }

    @GetMapping(value = "/location")
    @ApiOperation(value = "1-04-3 获取定位列表", notes = "包含开放的城市列表和热门城市列表,并根据首字母进行分组")
    public Json<LocationMeta> listAreaLocation(ListAreaLocationParam param) {
        return ResultUtil.genSuccessResult(locationService.listLocation(param));
    }

    @GetMapping(value = "/info/{code}")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
    })
    @ApiOperation(value = "1-04-4 根据code获取区域信息", notes = "")
    public Json<AreaInfo> getAreaInfo(@PathVariable String code, BasicParam basicParam) {
        if ("undefined".equals(code)) {
            return ResultUtil.genFailedResult("code非法，无法定位:" + code);
        }
        return ResultUtil.genSuccessResult(areaInfoService.getAreaInfo(code, basicParam));
    }

    @GetMapping(value = "/speech")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "code", value = "区域编号 一般为12位"),
            @ApiImplicitParam(name = "type", value = "话术类型 1：微信 2：朋友圈 5:小程序微信 6：小程序朋友圈 11:聊天室分享配置 12：邀请分享激活VIP 13:联系商家信息")
    })
    @ApiOperation(value = "1-04-5 根据code获取区域的话术", notes = "在分享至微信的时候,需要显示的文字：包括微信、朋友圈的话术，其中包含内容和ID")
    public Json<LocationRelationDTO> getAreaSpeech(@RequestParam String code, @RequestParam Byte type) {

        LocationRelationDTO locationRelation = locationRelationService.getLocationRelation(code, type);
        return ResultUtil.genSuccessResult(locationRelation);
    }

    @GetMapping(value = "/location/{code}/customer")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
            @ApiImplicitParam(name = "type", value = "类型0：客服微信 1：夺宝关注公众号 2：达人关注公众号 3：订单关注公众号"),
    })
    @ApiOperation(value = "1-04-7 根据地区code获取客服信息", notes = "获取客服信息-二维码和微信号")
    public ResponseJson<CustomerServiceDTO> getCustomerServiceByCode(@PathVariable String code,
                                                                     @RequestParam(value = "type", required = false) Byte type) {

        try {
            CustomerServiceDTO customerServiceDTO = locationService.getCustomerServiceInfo(code, type);
            if (null == customerServiceDTO) {
                return ResponseJson.build(Message.build(false).setMessage("该地区客服信息不存在"));
            }
            return ResponseJson.ok(customerServiceDTO);
        } catch (Exception e) {
            LOG.error("根据地区code获取客服信息异常", e);
            return ResponseJson.build(Message.build(false).setMessage("根据地区code获取客服信息异常"));
        }
    }

    @GetMapping(value = "/public/speech")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "code", value = "区域编号 一般为12位"),
            @ApiImplicitParam(name = "type", value = "话术类型 1：微信 2：朋友圈 5:小程序微信 6：小程序朋友圈,11聊天室分享配置")
    })
    @ApiOperation(value = "1-04-8 站外根据code获取区域的话术", notes = "在分享至微信的时候,需要显示的文字：包括微信、朋友圈的话术，其中包含内容和ID")
    public Json<LocationRelationDTO> getAreaSpeechForPublic(@RequestParam String code, @RequestParam Byte type) {
        LocationRelationDTO locationRelation = locationRelationService.getLocationRelation(code, type);
        return ResultUtil.genSuccessResult(locationRelation);
    }

    @GetMapping(value = "/location/{code}/group/customer/phone")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
    })
    @ApiOperation(value = "1-04-9 根据地区code获取团购客服电话", notes = "获取团购客服电话")
    public Json<GroupCustomerPhoneDTO> getGroupCustomerServiceByCode(@PathVariable String code) {

        try {
            GroupCustomerPhoneDTO groupCustomerPhoneDTO = locationService.getGroupCustomerPhoneServiceInfo(code);
            if (null == groupCustomerPhoneDTO) {
                return ResultUtil.genFailedResult("获取团购客服电话失败");
            }

            return ResultUtil.genSuccessResult(groupCustomerPhoneDTO);
        } catch (Exception e) {
            LOG.error("获取团购客服电话异常", e);
            return ResultUtil.genFailedResult("获取客服信息异常");
        }
    }

    @GetMapping(value = "/public/{code}/officialAccount")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "code", value = "区域编号 一般为12位", required = true),
    })
    @ApiOperation(value = "1-04-10 根据地区code获取公众号信息", notes = "获取公众号信息")
    public ResponseJson<OfficialAccountDTO> getOfficialAccountByCode(@PathVariable String code) {
        return ResponseJson.ok(locationService.getOfficialAccountInfo(code));
    }
}
